@@ -94,7 +94,7 @@
 #define HAVE_TIME_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_UTIME_H 1
-#define HAVE_VARARGS_H 1
+/* #undef HAVE_VARARGS_H */
 /* #undef HAVE_SYS_UTIME_H */
 #define HAVE_SYS_WAIT_H 1
 #define HAVE_SYS_PARAM_H 1
@@ -102,12 +102,6 @@
 /* Libraries */
 /* #undef HAVE_LIBWRAP */
 /* #undef HAVE_SYSTEMD */
-/* #undef HAVE_CRC32_VPMSUM */
-
-/* Support ARMv8 crc + crypto  */
-/* #undef HAVE_ARMV8_CRC */
-/* #undef HAVE_ARMV8_CRYPTO */
-/* #undef HAVE_ARMV8_CRC_CRYPTO_INTRINSICS */
 
 /* Does "struct timespec" have a "sec" and "nsec" field? */
 /* #undef HAVE_TIMESPEC_TS_SEC */
@@ -278,10 +272,10 @@
   #define SIZEOF_SIZE_T  SIZEOF_LONG
 #else
 /* No indentation, to fetch the lines from verification scripts */
-#define SIZEOF_LONG   8
-#define SIZEOF_VOIDP  8
-#define SIZEOF_CHARP  8
-#define SIZEOF_SIZE_T 8
+#define SIZEOF_LONG   4
+#define SIZEOF_VOIDP  4
+#define SIZEOF_CHARP  4
+#define SIZEOF_SIZE_T 4
 #endif
 
 #define HAVE_LONG 1
@@ -296,7 +290,7 @@
 /* #undef HAVE_UCHAR */
 #define SIZEOF_UINT 4
 #define HAVE_UINT 1
-#define SIZEOF_ULONG 8
+#define SIZEOF_ULONG 4
 #define HAVE_ULONG 1
 /* #undef SIZEOF_INT8 */
 /* #undef HAVE_INT8 */
@@ -334,7 +328,7 @@
     #define WORDS_BIGENDIAN 1
   #endif
 #else
-#define WORDS_BIGENDIAN 1 
+/* #undef WORDS_BIGENDIAN */
 #endif
 
 /* Define to `__inline__' or `__inline' if that's what the C compiler calls
@@ -395,8 +389,8 @@
 #define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "OpenBSD"
-#define MACHINE_TYPE "sparc64"
-#define DEFAULT_MACHINE "sparc64"
+#define MACHINE_TYPE "i386"
+#define DEFAULT_MACHINE "i386"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -531,16 +525,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 5
-#define MYSQL_VERSION_PATCH 6
+#define MYSQL_VERSION_PATCH 7
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.5.6"
+#define PACKAGE_STRING "MySQL Server 10.5.7"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.5.6"
-#define VERSION "10.5.6"
+#define PACKAGE_VERSION "10.5.7"
+#define VERSION "10.5.7"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
